import os
import sys

if not os.environ.has_key('DIST_CHECK'):
    sys.path = ['..', '../gnomevfs', '../gnomecanvas'] + sys.path

import ltihooks
ltihooks.install()

import bonobo
import gnomevfs
import bonobo.ui
import gconf
import gnome
import gnome.ui
import gnomecanvas

ltihooks.uninstall()
